==> formant-1.230.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/device_configuration_template/device_configuration_template_controller_list.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import AuthenticatedClient
from ...models.device_configuration_template_list_response import DeviceConfigurationTemplateListResponse
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
) -> Dict[str, Any]:
    url = "{}/device-configuration-templates/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[DeviceConfigurationTemplateListResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = DeviceConfigurationTemplateListResponse.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[DeviceConfigurationTemplateListResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
) -> Optional[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
) -> Optional[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed

==> formant-1.268.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/device_configuration_template/device_configuration_template_controller_list.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import AuthenticatedClient
from ...models.device_configuration_template_list_response import \
    DeviceConfigurationTemplateListResponse
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,

) -> Dict[str, Any]:
    url = "{}/device-configuration-templates/".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    

    

    return {
	    "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[DeviceConfigurationTemplateListResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = DeviceConfigurationTemplateListResponse.from_dict(response.json())



        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[DeviceConfigurationTemplateListResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,

) -> Response[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """


    kwargs = _get_kwargs(
        client=client,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)

def sync(
    *,
    client: AuthenticatedClient,

) -> Optional[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """


    return sync_detailed(
        client=client,

    ).parsed

async def asyncio_detailed(
    *,
    client: AuthenticatedClient,

) -> Response[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """


    kwargs = _get_kwargs(
        client=client,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(response=response)

async def asyncio(
    *,
    client: AuthenticatedClient,

) -> Optional[DeviceConfigurationTemplateListResponse]:
    """List

     List device configuration templates
    Resource: devices
    Authorized roles: administrator

    Returns:
        Response[DeviceConfigurationTemplateListResponse]
    """


    return (await asyncio_detailed(
        client=client,

    )).parsed
